The London Perl and Raku Workshop takes place on 26th Oct 2024. If your company depends on Perl, please consider sponsoring and/or attending.

NAME

DBIx::Class::RandomStringColumns - Implicit random string columns

SYNOPSIS

  pacakge Proj::Data;
  use base qw(DBIx::Class);
  __PACKAGE__->load_components(qw/RandomStringColumns Core DB/);

  package Proj::Data::Artist;
  use base qw(Proj::Data);
  __PACKAGE__->random_string_columns('rid', {length => 10});

DESCRIPTION

This DBIx::Class component resembles the behaviour of Class::DBI::Plugin::RandomStringColumn, to make some columns implicitly created as random string.

Note that the component needs to be loaded before Core.

METHODS

random_string_columns

AUTHORS

Kan Fushihara <kan at mobilefactory.jp>

LICENSE

You may distribute this code under the same terms as Perl itself.